==> solstice-1.3.1%2B1.21.1-sources.jar: me/alexdevs/solstice/locale/Locale.java <==
package me.alexdevs.solstice.locale;

import eu.pb4.placeholders.api.PlaceholderContext;
import me.alexdevs.solstice.api.text.Format;
import net.minecraft.class_2561;
import java.util.Map;
import java.util.function.Supplier;

public class Locale {
    public final String id;

    private final Supplier<LocaleManager.LocaleModel> localeSupplier;

    public Locale(String id, Supplier<LocaleManager.LocaleModel> localeSupplier) {
        this.id = id;
        this.localeSupplier = localeSupplier;
    }

    public String raw(String path) {
        String fullPath;
        if (path.startsWith("~")) {
            fullPath = "shared." + path.substring(1);
        } else if (path.startsWith("/")) {
            fullPath = path.substring(1);
        } else {
            fullPath = "module." + this.id + "." + path;
        }

        return localeSupplier.get().get(fullPath);
    }

    public class_2561 get(String path) {
        var src = this.raw(path);
        return Format.parse(src);
    }

    public class_2561 get(String path, PlaceholderContext context) {
        var src = this.raw(path);
        return Format.parse(src, context);
    }

    public class_2561 get(String path, Map<String, class_2561> placeholders) {
        var src = this.raw(path);
        return Format.parse(src, placeholders);
    }

    public class_2561 get(String path, PlaceholderContext context, Map<String, class_2561> placeholders) {
        var src = this.raw(path);
        return Format.parse(src, context, placeholders);
    }
}

==> solstice-1.9.2%2B1.20.1-sources.jar: me/alexdevs/solstice/locale/Locale.java <==
package me.alexdevs.solstice.locale;

import eu.pb4.placeholders.api.PlaceholderContext;
import me.alexdevs.solstice.api.text.Format;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import java.util.Map;
import java.util.function.Supplier;

public class Locale {
    public final class_2960 id;

    private final Supplier<Map<String, String>> localeSupplier;

    public Locale(class_2960 id, Supplier<Map<String, String>> localeSupplier) {
        this.id = id;
        this.localeSupplier = localeSupplier;
    }

    public String raw(String path) {
        String fullPath;
        if (path.startsWith("~")) {
            fullPath = "shared." + path.substring(1);
        } else if (path.startsWith("/")) {
            fullPath = path.substring(1);
        } else {
            var id = this.id.toString().replace(':', '.');
            fullPath = "module." + id + "." + path;
        }

        return localeSupplier.get().get(fullPath);
    }

    public class_2561 get(String path) {
        var src = this.raw(path);
        return Format.parse(src);
    }

    public class_2561 get(String path, PlaceholderContext context) {
        var src = this.raw(path);
        return Format.parse(src, context);
    }

    public class_2561 get(String path, Map<String, class_2561> placeholders) {
        var src = this.raw(path);
        return Format.parse(src, placeholders);
    }

    public class_2561 get(String path, PlaceholderContext context, Map<String, class_2561> placeholders) {
        var src = this.raw(path);
        return Format.parse(src, context, placeholders);
    }
}
